You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beam.apache.org by ar...@apache.org on 2021/04/09 10:44:53 UTC
[beam] branch master updated (974c2de -> cae0652)
This is an automated email from the ASF dual-hosted git repository.
aromanenko pushed a change to branch master
in repository https://gitbox.apache.org/repos/asf/beam.git.
from 974c2de Merge pull request #14492 from ihji/BEAM-12141
add 4805a62 Decrease the memorized backlog from 5s to 1s
new cae0652 Merge pull request #14478: Decrease the memorized backlog from 5s to 1s
The 1 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails. The revisions
listed as "add" were already present in the repository and have only
been added to this reference.
Summary of changes:
.../src/main/java/org/apache/beam/sdk/io/kafka/ReadFromKafkaDoFn.java | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
[beam] 01/01: Merge pull request #14478: Decrease the memorized
backlog from 5s to 1s
Posted by ar...@apache.org.
This is an automated email from the ASF dual-hosted git repository.
aromanenko pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/beam.git
commit cae0652db2c91e5ddf7f39ea052c4a1bc812f6ad
Merge: 974c2de 4805a62
Author: Alexey Romanenko <33...@users.noreply.github.com>
AuthorDate: Fri Apr 9 12:43:34 2021 +0200
Merge pull request #14478: Decrease the memorized backlog from 5s to 1s
.../src/main/java/org/apache/beam/sdk/io/kafka/ReadFromKafkaDoFn.java | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)